@@ -1,9 +1,10 @@
 #ifndef LISTIMPORT_H
 #define LISTIMPORT_H
 
-#import "List.h"
-
 namespace Shopper {
+	// forward declaration
+	class List;
+
 	class ListImport {
 	public:
 		static List* from_plaintext(QString filename);
