@@ -114,17 +114,22 @@ MainWindow::MainWindow(QString file) :
 	
 	// Toolbars - shown/hidden according to view
     editBar = new QToolBar(tr("Edit"));
+	editBar->setFloatable(false);
+	editBar->setMovable(false);
 	editBar->setIconSize(QSize(64,64));
 	editBar->addAction(addItemAct);
     editBar->addAction(manageCatAct);
-    editBar->addSeparator();
     modeBar = new QToolBar(tr("Mode"));
+	modeBar->setFloatable(false);
+	modeBar->setMovable(false);
 	modeBar->setIconSize(QSize(64,64));
     modeBar->addAction(fullListAct);
     modeBar->addAction(whatsLeftAct);
     modeBar->addAction(makingListAct);
 
 	navBar = new QToolBar(tr("Navigation"));
+	navBar->setFloatable(false);
+	navBar->setMovable(false);
 	navBar->setIconSize(QSize(64,64));
 	navBar->addAction(prevAct);
 //    editBar->addAction(toggleWhatsLeftAct); // ??? idea
@@ -347,6 +352,7 @@ void MainWindow::on_action_file()
 
 void MainWindow::on_action_file_new()
 {
+	if (dialog_active == true) return;
 	// FIXME: This really ought to check if the user *WANTS* to save...
 	if (mylist)
 		on_action_file_save();
@@ -390,11 +396,17 @@ void MainWindow::on_action_file_new()
 }
 void MainWindow::on_action_file_open()
 {
+	if (dialog_active == true) return;
 	// Get a filename
-	QFileDialog dialog(this);
 	QString dir = filename.isEmpty() ? QString(HOME_DIR)+ QString(DEFAULT_LIST) : filename ;
 	//Handle the response:
-	if (!(filename = dialog.getOpenFileName(this, "Select a list",dir, tr("Lists (*)"))).isEmpty()) {
+	dialog_active = true; // not modal
+	filename = QFileDialog::getOpenFileName(this,
+											"Select a list",
+											dir,
+											tr("Lists (*.xml)"));
+	dialog_active = false;
+	if (! filename.isEmpty()) {
 		// Open file and create a view from it.
 		create_list_view(Shopper::List::from_file(filename));
 		writeSettings(); // FIXME this should be on success
@@ -405,11 +417,17 @@ void MainWindow::on_action_file_open()
 }
 void MainWindow::on_action_file_import()
 {
+	if (dialog_active == true) return;
 	// Get a filename
-	QFileDialog dialog(this);
 	QString dir = filename.isEmpty() ? QString(HOME_DIR)+ QString(DEFAULT_LIST) : filename ;
 	//Handle the response:
-	if (!(filename = dialog.getOpenFileName(this, "Select a list",dir, tr("Lists (*)"))).isEmpty()) {
+	dialog_active = true;
+	filename = QFileDialog::getOpenFileName(this,
+										   "Select a list",
+										   dir,
+										   tr("Lists (*.xml)"));
+	dialog_active = false;
+	if (! filename.isEmpty()) {
 		// Open file and create a view from it.
 		create_list_view(Shopper::ListImport::from_plaintext(filename));
 		// treat it like a new list ?
@@ -424,6 +442,7 @@ void MainWindow::on_action_file_import()
 ////////////////////////////////////////////////////////////////
 void MainWindow::on_action_file_save()
 {
+	if (dialog_active == true) return;
 	DEBUG("Saving....\n");
 	if (filename.isEmpty()) {
 		on_action_file_saveas();
@@ -433,11 +452,19 @@ void MainWindow::on_action_file_save()
 }
 void MainWindow::on_action_file_saveas()
 {
+	if (dialog_active == true) return;
 	// Get a filename
-	QFileDialog dialog(this);
 	QString dir = HOME_DIR+(filename==""?DEFAULT_LIST:filename);
-	//Handle the response:
-	if (!(filename = dialog.getSaveFileName(this, "Save list as", dir, tr("Lists (*.xml)"))).isEmpty()) {
+	dialog_active = true;
+	filename = QFileDialog::getSaveFileName(this,
+									  "Save list as",
+									  dir,
+									  tr("Lists (*.xml)"),
+									  NULL,
+									  QFileDialog::HideNameFilterDetails
+		);
+	dialog_active = false;
+	if (! filename.isEmpty()) {
 		// Open file and create a view from it.
 		writeSettings();
 		mylist->to_file(filename);
